==> jc-1.4.0.tar.gz: gnu/java/rmi/dgc/DGCImpl.h <==
// public class gnu.java.rmi.dgc.DGCImpl

// class file dependencies
// @dep_class 97c4e249bce65be5 gnu_java_rmi_dgc_DGCImpl
// @dep_class d323d77b779ec5d1 gnu_java_rmi_server_UnicastRef
// @dep_class d4af877755203117 gnu_java_rmi_server_UnicastServerRef
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_UnicastServerRef

#include "gnu/java/rmi/server/UnicastServerRef.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_dgc_Lease$object;
struct _jc_java_rmi_dgc_VMID$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$refs	_jc_gnu_java_rmi_dgc_DGCImpl$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$object	_jc_gnu_java_rmi_dgc_DGCImpl$object;

typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct	_jc_gnu_java_rmi_dgc_DGCImpl$fields_struct;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vtable	_jc_gnu_java_rmi_dgc_DGCImpl$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vtype	_jc_gnu_java_rmi_dgc_DGCImpl$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct {
	jlong	LEASE__5fVALUE;
};
extern _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct _jc_gnu_java_rmi_dgc_DGCImpl$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *);

// Virtual methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$clean$7ba6dfeaa3943ecf(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_VMID$object *, jboolean);
extern struct _jc_java_rmi_dgc_Lease$object *_jc_gnu_java_rmi_dgc_DGCImpl$method$dirty$1f598e15ac48267e(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_Lease$object *);
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$clean$7ba6dfeaa3943ecf;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$dirty$1f598e15ac48267e;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$vmethods {
	void	(*clean$7ba6dfeaa3943ecf)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_VMID$object *, jboolean);
	struct _jc_java_rmi_dgc_Lease$object	*(*dirty$1f598e15ac48267e)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_Lease$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *);
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_UnicastRef$vmethods	gnu_java_rmi_server_UnicastRef;
	_jc_gnu_java_rmi_server_UnicastServerRef$vmethods	gnu_java_rmi_server_UnicastServerRef;
	_jc_gnu_java_rmi_dgc_DGCImpl$vmethods	gnu_java_rmi_dgc_DGCImpl;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs {
	struct _jc_java_util_Hashtable$object	*leaseCache;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs	gnu_java_rmi_dgc_DGCImpl;
    _jc_gnu_java_rmi_server_UnicastServerRef$sub_refs	gnu_java_rmi_server_UnicastServerRef;
    _jc_gnu_java_rmi_server_UnicastRef$sub_refs	gnu_java_rmi_server_UnicastRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_UnicastRef$sub_nonrefs	gnu_java_rmi_server_UnicastRef;
    _jc_gnu_java_rmi_server_UnicastServerRef$sub_nonrefs	gnu_java_rmi_server_UnicastServerRef;
    _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$object {
	_jc_gnu_java_rmi_dgc_DGCImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl$vtype _jc_gnu_java_rmi_dgc_DGCImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/dgc/DGCImpl.h <==
// public class gnu.java.rmi.dgc.DGCImpl

// class file dependencies
// @dep_class 8aea41a9d6684919 gnu_java_rmi_dgc_DGCImpl
// @dep_class e2bfe5db49f6da1b gnu_java_rmi_server_UnicastRef
// @dep_class d4af877755203117 gnu_java_rmi_server_UnicastServerRef
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_rmi_server_UnicastServerRef

#include "gnu/java/rmi/server/UnicastServerRef.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_dgc_Lease$object;
struct _jc_java_rmi_dgc_VMID$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$refs	_jc_gnu_java_rmi_dgc_DGCImpl$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$object	_jc_gnu_java_rmi_dgc_DGCImpl$object;

typedef struct _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct	_jc_gnu_java_rmi_dgc_DGCImpl$fields_struct;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vtable	_jc_gnu_java_rmi_dgc_DGCImpl$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl$vtype	_jc_gnu_java_rmi_dgc_DGCImpl$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct {
	jlong	LEASE__5fVALUE;
};
extern _jc_gnu_java_rmi_dgc_DGCImpl$fields_struct _jc_gnu_java_rmi_dgc_DGCImpl$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$clean$7ba6dfeaa3943ecf(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_VMID$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_dgc_Lease$object *_jc_gnu_java_rmi_dgc_DGCImpl$method$dirty$1f598e15ac48267e(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_dgc_DGCImpl$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$clean$7ba6dfeaa3943ecf;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$dirty$1f598e15ac48267e;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$vmethods {
	void	(*clean$7ba6dfeaa3943ecf)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_VMID$object *, jboolean) _JC_JCNI_ATTR;
	struct _jc_java_rmi_dgc_Lease$object	*(*dirty$1f598e15ac48267e)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *, struct _jc_object_array *, jlong, struct _jc_java_rmi_dgc_Lease$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_UnicastRef$vmethods	gnu_java_rmi_server_UnicastRef;
	_jc_gnu_java_rmi_server_UnicastServerRef$vmethods	gnu_java_rmi_server_UnicastServerRef;
	_jc_gnu_java_rmi_dgc_DGCImpl$vmethods	gnu_java_rmi_dgc_DGCImpl;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs {
	struct _jc_java_util_Hashtable$object	*leaseCache;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl$sub_refs	gnu_java_rmi_dgc_DGCImpl;
    _jc_gnu_java_rmi_server_UnicastServerRef$sub_refs	gnu_java_rmi_server_UnicastServerRef;
    _jc_gnu_java_rmi_server_UnicastRef$sub_refs	gnu_java_rmi_server_UnicastRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_UnicastRef$sub_nonrefs	gnu_java_rmi_server_UnicastRef;
    _jc_gnu_java_rmi_server_UnicastServerRef$sub_nonrefs	gnu_java_rmi_server_UnicastServerRef;
    _jc_gnu_java_rmi_dgc_DGCImpl$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl$object {
	_jc_gnu_java_rmi_dgc_DGCImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl$vtype _jc_gnu_java_rmi_dgc_DGCImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl_H_ */
